@@ -393,7 +393,7 @@ class Vector:
         Args:
             v: A sequence of dX,dY,dZ deltas
         """
-        self._a: np.ndarray = np.array(v, dtype="float64")  # storage as Numpy array
+        self._a: np.ndarray = np.array(v)  # storage as Numpy array
 
     @classmethod
     def from_array(cls, a: np.ndarray, copy=True):
@@ -531,7 +531,7 @@ class Point:
         Args:
             p: sequence of X,Y,Z coordinates
         """
-        self._a: np.ndarray = np.array(p, dtype="float64")  # storage as Numpy array
+        self._a: np.ndarray = np.array(p)  # storage as Numpy array
 
     @classmethod
     def from_array(cls, a: np.ndarray, copy=True):
@@ -640,6 +640,18 @@ class Plane:
     normal: Vector
     point: Point
 
+    def as_abcd(self) -> Tuple[float, float, float, float]:
+        """ABCD components of the plane
+
+        Defining the plane via
+        a*x + b*y + c*z + d = 0
+
+        Returns:
+            tuple (a,b,c,d)
+        """
+        n = normalized_vector(self.normal.as_array())
+        return (*n, -1 * dot_vec_vec(n, self.point.as_array()))
+
 
 class RotationMatrix:
     """A 3x3 rotation matrix.
