@@ -1,6 +1,4 @@
-import pytest
-
-from geo3d import Vector
+from geo3d import Vector, Point
 import numpy as np
 
 
@@ -9,6 +7,16 @@ def test_vector_from_array():
     assert p[2] == 3
 
 
+def test_vector_from_vector():
+    p = Vector(Vector([1, 2, 3]))
+    assert p[2] == 3
+
+
+def test_vector_from_point():
+    p = Vector(Point([1, 2, 3]))
+    assert p[2] == 3
+
+
 def test_vector_from_tuple():
     p = Vector((1, 2, 3))
     assert p[2] == 3
